<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// M
	'medias_description' => 'Merañ ar mediaoù SPIP',
	'medias_slogan' => 'Merañ ar mediaoù e SPIP',
];
